@@ -181,6 +181,12 @@ public:
 			UI_LAYOUT_TABBED
 	};
 
+	enum UI_SCALING_POLICY {
+		UI_SCALING_SMALLER,
+		UI_SCALING_SYSTEM,
+		UI_SCALING_LARGER
+	};
+
 	QString				__lastspatternDirectory;
 	QString				__lastsampleDirectory; // audio file browser
 	bool				__playsamplesonclicking; // audio file browser
@@ -385,7 +391,13 @@ public:
 	int				getDefaultUILayout();
 	void			setDefaultUILayout( int layout);
 
+	int				getUIScalingPolicy();
+	void			setUIScalingPolicy( int nPolicy );
+
 	// General
+	const QString&	getPreferredLanguage();
+	void			setPreferredLanguage( const QString& sLanguage );
+
 	void			setRestoreLastSongEnabled( bool restore );
 	void			setRestoreLastPlaylistEnabled( bool restore );
 	void			setUseRelativeFilenamesForPlaylists( bool value );
@@ -435,7 +447,6 @@ public:
 	const QString&	getQTStyle();
 	void			setQTStyle( const QString& sStyle );
 
-
 	const QString&	getApplicationFontFamily();
 	void			setApplicationFontFamily( const QString& family );
 
@@ -675,6 +686,7 @@ private:
 	QString					m_sQTStyle;
 	int						m_nLastOpenTab;
 	int						m_nDefaultUILayout;
+	int						m_nUIScalingPolicy;
 	bool					m_bShowPlaybackTrack;
 
 	QString					applicationFontFamily;
@@ -699,6 +711,7 @@ private:
 	WindowProperties		m_ladspaProperties[MAX_FX];
 
 	UIStyle*				m_pDefaultUIStyle;
+	QString					m_sPreferredLanguage;
 
 	//Appearance: SongEditor coloring
 	int						m_nColoringMethod;
@@ -812,8 +825,25 @@ inline void Preferences::setDefaultUILayout( int layout){
 	m_nDefaultUILayout = layout;
 }
 
+inline int Preferences::getUIScalingPolicy() {
+	return m_nUIScalingPolicy;
+}
+
+inline void Preferences::setUIScalingPolicy( int nPolicy ) {
+	m_nUIScalingPolicy = nPolicy;
+}
+
+
 
 // General
+inline const QString& Preferences::getPreferredLanguage() {
+	return m_sPreferredLanguage;
+}
+
+inline void Preferences::setPreferredLanguage( const QString& sLanguage ) {
+	m_sPreferredLanguage = sLanguage;
+}
+
 inline void Preferences::setRestoreLastSongEnabled( bool restore ) {
 	m_brestoreLastSong = restore;
 }
